@@ -36,7 +36,7 @@
 
 /* Defines the poppler version. */
 #ifndef POPPLER_VERSION
-#define POPPLER_VERSION "23.05.0"
+#define POPPLER_VERSION "23.08.0"
 #endif
 
 /* Use single precision arithmetic in the Splash backend */
@@ -74,11 +74,6 @@
 #define ENABLE_LIBPNG 1
 #endif
 
-/* Use zlib instead of builtin zlib decoder. */
-#ifndef ENABLE_ZLIB
-#define ENABLE_ZLIB 1
-#endif
-
 /* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'.
    */
 #ifndef HAVE_DIRENT_H
